@@ -1,5 +1,5 @@
 from .event import EventRouter, Event
-from util import int_to_ordinal
+from .util import int_to_ordinal
 import asyncio
 import contextlib
 
