@@ -109,6 +109,7 @@ class EventMuxer(AutoRepr):
 
     def add_listener(self, func: ty.Union[EventFunction, EventWaiter]):
         container = self.waiters if isinstance(func, EventWaiter) else self.funcs
+        print(f"adding {func}")
         container.add(func)
         # self.one_times.add(one_time)
 
@@ -118,7 +119,7 @@ class EventMuxer(AutoRepr):
 
     @router.setter
     def router(self, router: EventRouter):
-        if self.__router:
+        if self.__router and router:
             raise ValueError(f"Attempted to set another router for {self}")
         else:
             self.__router = router
@@ -153,7 +154,7 @@ class EventRouter(AutoRepr):
                     return await func(*event.args, **event.kwargs)
 
                 _func = __decompose
-            logging.debug("[%s] Attaching endpoint %s as <%s>", self, func.__name__, name.lower())
+            logging.debug("[%s] Attaching endpoint %s as <%s>", self, func, name.lower())
 
             return self.register_listener(name=name.lower(), listener=_func)
             # return func
